Pērciet BMW X6 M 2016 4.4 423 kW F86 2016 ar patiesu nobraukumu 133543 km Rīgā oficiālā dīlera salonā
Description: Iegādājaties mazlietotu BMW X6 M ar nobraukumu 133543 km. Mazlietots BMW X6 M 2016 4.4 423 kW F86 Automātiskā par 54900 EUR, mazlietotu automobiļu tirdzniecības vietā Inchcape Certified Rīgā.

20

# BMW X6 M 2016 4.4 423 kW F86, 133543 km

54 900 € (Ieskaitot PVN 21%)
€ 789,18 / mēn.*
Salons:
Inchcape Motors Dārzciema
Dārzciema iela 64A
Tālrunis:
+371 (67) 82-8600
Uzzināt vairāk ONLINE konsultācija Saņemt AutoDNA i Sazināties WhatsApp
Izlaiduma gads
2016-06-17
Dzinējs
Benzīns
Nobraukums
133 543
Pārnesumkārba
Automātiskā
Piedziņas veids
AWD
Virsbūves tips
SUV
Tehniskie dati
Aprīkojums
Pamatinformācija
Zīmols
BMW
Modelis
X6 M
Modifikācija
2016 4.4 423 kW F86
Nobraukums
133 543
VIN
WBSKW810100G93368
Izlaiduma gads
2016
Virsbūves tips
SUV
Piedziņas veids
AWD
Pārnesumkārba
Automātiskā
Interjers

- Interjers (ādas apdare)
- Interjera krāsa (melna)
- Sportiska stila sēdekļi
- Elektriski regulējami sēdekļi (priekšējie, ar atmiņu)
- Regulējams stūres novietojums
- Multistūre
- Apsildāmi sēdekļi (priekšējie, aizmugurējie)
- Regulējama sēdekļu muguras daļa (vadītāja, pasažiera)
- Priekšējais elkoņbalsts (ar mantu glabātuvi)

Informācijas sistēmas

- Bluetooth
- WiFi hotspot
- Digitāls instrumentu panelis
- Audiosistēma (rūpnīcas, CD, MP3, USB)
- LCD ekrāns
- Navigācijas sistēma
- Brīvroku sistēma
- Radio

Papildus aprīkojums

- Vieglmetāla diski
- Riepu spiediena kontrole
- Start-stop sistēma
- Āra temperatūras mērītājs
- Sporta pakotne
- Bremžu palīgsistēma braukšanai no kalna
- Kalnābraukšanas asistēšana
- Servisa grāmatiņa
- Otra atslēga
- Pilnpiedziņa 4x4

Drošība

- Stūres pastiprinātājs (pielāgojoties ātrumam)
- Centrālā atslēga (ar tālvadību)
- Gaisa spilveni (sānu aizkari, atslēdzams pasažiera pusē)
- Elektroniska rokasbremze
- Signalizācija (ar salona sensoriem, ar divu veidu aizsardzību)
- Elektroniskā stabilitātes sistēma (ESP)
- Bremzēšanas spēka sadale
- Isofix bērnu sēdeklīšu stiprinājumi
- Lietus sensors
- LED lukturi
- Miglas lukturi
- Adaptīvie lukturi

Komforts

- Gaisa kondicionieris
- Klimata kontrole (trīszonu, Klimata kontrole aizmugurē)
- Elektriski regulējami sānu spoguļi (apsildāmi, ar atmiņu)
- Elektriski atverami/aizverami stikli
- Kruīza kontrole
- Bezatslēgu sistēma
- Parkošanās kamera
- Projekcija vējstiklā (Head up)
- Parkošanās sensori (priekšējie, aizmugurejie)
- Salona gaisa filtrs

## Priekšlīzinga kalkulators

Par konkrētu līzinga piedāvājumu interesējieties mūsu salonos

## Operatīvais līzings

€ / mēn.

Pirmā iemaksa: EUR

- 10%
- 20%
- 30%
- 40%
- 50%

Atlikusī vērtība

Līzinga periods, gadi

- 3
- 4
- 5

## Finanšu līzings

€ / mēn.

Līzinga periods, gadi

- 3
- 4
- 5

Pirmā iemaksa: EUR

- 10%
- 20%
- 30%
- 40%
- 50%

Inchcape Motors Latvia SIA piedāvā finansējumu sadarbībā ar vadošajām līzinga kompānijām.

Aprēķins veikts, ņemot vērā izvēlēta automobiļa cenu operatīvajā līzingā ar 10% iemaksu uz 60 mēnešiem ar 35% atlikušo vērtību un 100 000 km limitu.

Procentu likme 2.95% + EURIBOR (6 mēn.), administrēšanas maksa 1,5%.Aizņemies atbildīgi, izvērtējot savas iespējas atmaksāt

## Speciālie piedāvājumi

Ford Ranger 2020 2.0 157 kW
54 900 €
Izlaiduma gads
2020-06-24
Virsbūves tips
SUV
Nobraukums
30 045
Piedziņas veids
AWD
Vairāk par auto
BMW X6 M 2016 4.4 423 kW F86
54 900 €
Izlaiduma gads
2016-06-17
Virsbūves tips
SUV
Nobraukums
133 543
Piedziņas veids
AWD
Vairāk par auto
Parādīt visu
Visaptveroša automašīnas tehniskā pārbaude
Automašīnu pārbaude atbilstoši Inchcape Certified standartiem.
Visaptverošs pakalpojumu klāsts
Finansēšana, apdrošināšana, testa braucieni, un citi pakalpojumi pieejami uz vietas.
Lietotas automašīnas garantija
6 mēnešu garantija Inchcape Latvija pārstāvētajām markām līdz 10 gadiem / 180 000 km
Jūsu automašīnas atpirkums (Trade-In)
Jūsu automašīna var kalpot kā pirmā iemaksa.
BMW X6 M 2016 4.4 423 kW F86

## Pieprasīt zvanu

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Paņem mašīnu

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Apmaiņa

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Novērtējiet

Automašīnas cenas iepriekšēja novērtēšana
Krāsa
Stūres novietojuma puse
Kreisā Labā
Kā es varu Jums piezvanīt
Jums ērts zvanu laiks
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Pieteikums AutoDNA atskaites saņemšanai
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Pieteikums ir pieņemts, paldies

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies

## Pieteikums ONLINE auto apskatei un konsultācijai

Piesakieties automašīnas apskatei un konsultācijai tiešsaistē un gaidiet mūsu pārstāvja zvanu, kura laikā varēsiet vienoties par Jums ērtāko tiešsaistes saziņas kanālu un laiku.

ONLINE saziņas laikā prezentēsim automašīnu, sniegsim ziņas par tās aprīkojumu un tehnisko stāvokli, mūsu pakalpojumiem un finansēšanas iespējām, kā arī atbildes uz visiem Jūsu jautājumiem.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Pieteikums ir pieņemts, paldies

Cienījamie klienti, vēršam Jūsu uzmanību, ka ievērojot valstī noteikto kārtību, sākot ar 15.11.2021. Inchcape Certified autocentri darbosies epidemioloģiski drošā vidē jeb “zaļajā drošības režīmā”.

Mēs turpinām veikt automašīnu tirdzniecību un servisa pakalpojumu sniegšanu, tomēr ceram uz Jūsu saprati, jo autocentra telpās konsultācijas varēsim sniegt tikai klientiem ar sadarbspējīgu vakcinācijas vai pārslimošanas sertifikātu. Klientus, kuriem nav zaļajam drošības režīmam atbilstoša sertifikāta, apkalposim ārpus autocentra - svaigā gaisā.

Uz tikšanos kādā no Inchcape Certified autocentriem!

## Inchcape Certified autocentri turpina darbu, piedāvājot attālinātu auto iegādi

Ievērojot valstī noteiktus ierobežojumus, visi Inchcape Certified autocentri turpina darbību, piedāvājot attālinātu auto iegādi, sākot no 21. oktobra līdz 15. novembrim. Darba laiks darba dienās no 9:00-18:00, bet brīvdienās būs slēgts.

Visas Inchcape Certified automašīnas būs iespējams apskatīt attālināti, kā arī veikt testa braucienu bez tieša kontakta ar uzņēmuma pārstāvi. Visu iegādes procesu būs iespējams veikt pilnībā attālināti caur e-pasta un/vai telefonisku saziņu ar autosalona tirdzniecības konsultantu. Tāpat rasti risinājumi arī attālinātai līzinga noformēšanai.

Pakalpojumu saņemšanas iespējas precizēt, zvanot uz mūsu informatīvajiem tālruņiem, e-pastiem vai nosūtot pieteikumu mājas lapā.

Sazināmies un esam pasargāti!

Cienījamie klienti, ievērojot Valstī noteikto kārtību, sākot ar 21.10.2021 Inchcape Certified tirdzniecības telpas būs slēgtas, tomēr automašīnas būs iespējams apskatīt bez tieša kontakta ar uzņēmuma pārstāvi un iegādāties attālināti.